@@ -1,6 +1,7 @@
 
-from typing import Tuple
+from typing import Tuple, List
 
+import datetime
 from sqlalchemy import distinct
 from sqlalchemy.sql import func
 import pandas as pd
@@ -30,6 +31,22 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
 
+    def get_last_trading_day(self, dt=datetime.datetime.today()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query_result = db_session.query(
+                    func.max(TradingDayList.datetime)
+                ).filter(
+                    TradingDayList.datetime < dt.date(),
+                ).one_or_none()
+                if query_result:
+                    return query_result[0]
+                else:
+                    return None
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
+
     def get_sector_info(self):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -169,8 +186,8 @@ class BasicDataApi(object):
     def delete_fund_nav(self, start_date, end_date):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                        FundNav
+                db_session.query(
+                    FundNav
                 ).filter(
                     FundNav.datetime >= start_date,
                     FundNav.datetime <= end_date,
@@ -202,15 +219,19 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
-    def get_stock_price(self, stock_list):
+    def get_stock_price(self, stock_list, begin_date: str = '', end_date: str = ''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                         StockPrice
                 ).filter(
-                        # We could query all fund_ids at one time
-                        StockPrice.stock_id.in_(stock_list),
-                    )
+                    # We could query all fund_ids at one time
+                    StockPrice.stock_id.in_(stock_list),
+                )
+                if begin_date:
+                    query = query.filter(StockPrice.datetime >= begin_date)
+                if end_date:
+                    query = query.filter(StockPrice.datetime <= end_date)
 
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
@@ -252,6 +273,21 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
 
+    def get_index_price_dt(self,start_date, end_date):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    IndexPrice
+                ).filter(
+                    IndexPrice.datetime >= start_date,
+                    IndexPrice.datetime <= end_date,
+                )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                return tag_df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
+
     def delete_index_price(self, index_id_list, start_date, end_date):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -361,14 +397,44 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundSize.__tablename__}')
 
+    def get_fund_status(self):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundStatusLatest,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundStatusLatest.__tablename__}')
+
     @staticmethod
-    def get_history_fund_size(fund_id):
+    def get_history_fund_size(fund_id: str = ''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     Fund_size_and_hold_rate,
+                )
+                if fund_id:
+                    query = query.filter(
+                        Fund_size_and_hold_rate.fund_id == fund_id
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_size_range(start_date, end_date):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    Fund_size_and_hold_rate.fund_id,
+                    Fund_size_and_hold_rate.datetime,
+                    Fund_size_and_hold_rate.size,
                 ).filter(
-                    Fund_size_and_hold_rate.fund_id == fund_id
+                    # 按报告日多选取3个月，保证初值可以fill出来
+                    Fund_size_and_hold_rate.datetime >= (pd.to_datetime(start_date) - datetime.timedelta(days=100)).strftime('%Y%m%d'),
+                    Fund_size_and_hold_rate.datetime <= end_date,
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
@@ -488,6 +554,25 @@ class BasicDataApi(object):
                 print(f'Failed to get time range data <err_msg> {e} from {StyleAnalysisStockFactor.__tablename__}')
                 return
 
+    def get_barra_cne5_risk_factor(self, start_date: str, end_date: str, stock_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    BarraCNE5RiskFactor
+                )
+                if stock_list:
+                    query = query.filter(
+                        BarraCNE5RiskFactor.stock_id.in_(stock_list)
+                    )
+                query = query.filter(
+                    BarraCNE5RiskFactor.datetime >= start_date,
+                    BarraCNE5RiskFactor.datetime <= end_date,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {BarraCNE5RiskFactor.__tablename__}')
+                return
+
     def get_fund_hold_asset(self, dt) -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -534,15 +619,31 @@ class BasicDataApi(object):
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
                 return
 
-    def get_fund_hold_bond(self, dt) -> pd.DataFrame:
+    def get_fund_hold_bond(self, dt: str = '') -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
-                        FundHoldBond
-                        ).filter(
-                            FundHoldBond.datetime == dt
-                        )
+                    FundHoldBond
+                )
+                if dt:
+                    query = query.filter(
+                        FundHoldBond.datetime == dt
+                    )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldBond.__tablename__}')
-                return
\ No newline at end of file
+                return
+
+    def delete_fund_rate(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    FundRate
+                ).filter(
+                    FundRate.fund_id.in_(fund_list),
+                    FundRate.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {FundRate.__tablename__}')
