@@ -1,5 +1,6 @@
 
 from collections import defaultdict
+import time
 import datetime
 import pandas as pd
 
@@ -50,6 +51,7 @@ class BasicDataHelper(object):
 
         # Get the mapping between order_book_id and fund_id (which is defined in this system)
         self._fund_id_mapping = BasicDataApi().get_fund_id_mapping()
+        self._timer: float = time.monotonic()
 
     def _get_fund_id_from_order_book_id(self, order_book_id: str, date: datetime.date) -> str:
         if order_book_id in self._fund_id_mapping:
@@ -71,4 +73,7 @@ class BasicDataHelper(object):
                     print(f'Failed to truncate table {table_name} <err_msg> {e}')
         df.to_sql(table_name, BasicDatabaseConnector().get_engine(), index=False, if_exists='append')
 
+        now: float = time.monotonic()
+        print(f'{table_name} costs {now - self._timer}s')
+        self._timer = now
         self._updated_count[table_name] += df.shape[0]
