@@ -201,10 +201,12 @@ class BasicDataPart1:
 
     def index_price(self, start_date, end_date):
         try:
+            raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
             # 多取N个交易日的数据
             start_date = datetime.datetime.strptime(start_date, '%Y%m%d') - datetime.timedelta(days=90)
             start_date = start_date.strftime('%Y%m%d')
             trading_day_df = BasicDataApi().get_trading_day_list(start_date, end_date)
+            trading_day_df = trading_day_df[trading_day_df.datetime <= raw_start_date_dt]
             assert trading_day_df.datetime.size >= INDEX_PRICE_EXTRA_TRADE_DAYS, f'should at least have {INDEX_PRICE_EXTRA_TRADE_DAYS} trading days'
             # del_date在start_date后边一天，确保可以正确计算ret等daily difference
             start_date = trading_day_df.datetime.array[-INDEX_PRICE_EXTRA_TRADE_DAYS]
@@ -230,7 +232,7 @@ class BasicDataPart1:
                 if not df.empty:
                     index_id_list.append(index_id)
 
-            end_date_dt = pd.to_datetime(end_date).date()
+            end_date_dt: datetime.date = pd.to_datetime(end_date, infer_datetime_format=True).date()
             index_list = ['sp500', 'dax30', 'n225']
             cm_index_list = ['sp500rmb', 'dax30rmb', 'n225rmb']
             for i, c in zip(index_list, cm_index_list):
@@ -241,12 +243,12 @@ class BasicDataPart1:
                 df = df[['close']]
                 df['index_id'] = c
                 df['ret'] = df.close / df.close.shift(1) - 1
-                df = df.loc[[end_date_dt], :]
+                df = df.loc[raw_start_date_dt:end_date_dt, :]
                 df_list.append(df.reset_index())
 
             df_list.append(cxindex_index_price[cxindex_index_price.datetime == end_date_dt])
             # 存进去美元计价的数据
-            df_list.append(yahoo_index_price[yahoo_index_price.datetime == end_date_dt])
+            df_list.append(yahoo_index_price[yahoo_index_price.datetime.between(raw_start_date_dt, end_date_dt)])
 
             df = pd.concat(df_list, ignore_index=True)
             # TODO: 改成原子提交下边两个操作
@@ -532,46 +534,48 @@ class BasicDataPart1:
             return False
 
     def fund_size_hold_rate_history(self):
-        start_date = '20100101'
-        end_date = '20200612'
+        start_date = '20200630'
+        end_date = '20200821'
         raw = self._raw_data_api
-        basic = BasicDataApi()
         fund_holding_rate = raw.get_em_fund_holding_rate(start_date=start_date)
-        fund_scale = raw.get_em_fund_scale(start_date=start_date, end_date=end_date)
         fund_holding_rate['fund_id'] = fund_holding_rate.apply(
             lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
-        fund_scale['fund_id'] = fund_scale.apply(
-            lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
         fund_holding_rate = fund_holding_rate.drop(['CODES', '_update_time'], axis=1).rename(columns={
             'DATES':'datetime',
             'HOLDPERSONALHOLDINGPCT':'personal_holds',
             'HOLDINSTIHOLDINGPCT':'institution_holds',
             'HOLDNUM': 'hold_num',
         })
-        fund_scale = fund_scale.drop(['CODES','_update_time'], axis=1).rename(columns={'DATES':'datetime','FUNDSCALE':'size'})
-        fund_scale = fund_scale.dropna(how='all').drop_duplicates(subset=['size','fund_id'],keep='first')
-        fund_holding_rate = fund_holding_rate.dropna(how='all')
+        fund_holding_rate = fund_holding_rate[fund_holding_rate.drop(columns='fund_id').notna().any(axis=1)]
+        fund_scale = raw.get_em_fund_scale(start_date=start_date, end_date=end_date)
+        fund_scale = fund_scale.pivot(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill').iloc[[-1], :].stack()
+        fund_scale = pd.DataFrame(fund_scale, columns=['FUNDSCALE']).reset_index()
+        fund_scale['fund_id'] = fund_scale.apply(
+            lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
+        fund_scale = fund_scale.drop(['CODES'], axis=1).rename(columns={'DATES': 'datetime', 'FUNDSCALE': 'size'})
+        fund_scale = fund_scale.dropna().drop_duplicates(subset=['size', 'fund_id'], keep='first')
+        fund_scale['datetime'] = pd.to_datetime(start_date).date()
         fund_list = list(set(fund_scale.fund_id))
         res = []
         for fund_id in fund_list:
-            fund_hold_i = fund_holding_rate[fund_holding_rate.fund_id == fund_id].drop('fund_id',axis=1).set_index('datetime')
-            fund_scale_i = fund_scale[fund_scale.fund_id == fund_id].drop('fund_id',axis=1).set_index('datetime')
+            fund_hold_i = fund_holding_rate[fund_holding_rate.fund_id == fund_id].drop(columns='fund_id').set_index('datetime')
+            fund_scale_i = fund_scale[fund_scale.fund_id == fund_id].drop(columns='fund_id').set_index('datetime')
             _df = fund_scale_i.join(fund_hold_i).fillna(method='ffill').reset_index()
             _df['fund_id'] = fund_id
             res.append(_df)
         df = pd.concat(res)
         df = df.drop_duplicates(subset=['datetime','fund_id'],keep='first')
-        df = df.fillna(0)
-        con_list = (df.personal_holds + df.institution_holds) == 100
-        df = df[con_list]
+        # con_list = (df.personal_holds + df.institution_holds) == 100
+        # df = df[con_list]
         self._data_helper._upload_basic(df, Fund_size_and_hold_rate.__table__.name)
 
     def fund_hold_asset(self, start_date: str, end_date: str):
         # history, update only on report date
         em_hold_asset = self._raw_data_api.get_em_fund_hold_asset(start_date, end_date)
+        em_hold_asset = em_hold_asset[em_hold_asset.CODES.str.contains('.OF')]
         em_hold_asset['CODES'] = em_hold_asset.apply(lambda x:
                             self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
-        em_hold_asset = em_hold_asset.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        em_hold_asset = em_hold_asset.dropna(subset=['CODES']).drop(columns='_update_time')
         name_dict = {
             'CODES': 'fund_id',
             'DATES': 'datetime',
@@ -586,14 +590,15 @@ class BasicDataPart1:
         self._data_helper._upload_basic(em_hold_asset, FundHoldAsset.__table__.name)
 
     def fund_hold_industry(self, end_date: str):
-        #history, update only on report date
+        # history, update only on report date
         em_hold_industry = self._raw_data_api.get_em_fund_hold_industry(end_date)
-        em_hold_industry['CODES'] = em_hold_industry.apply(lambda x :
+        em_hold_industry = em_hold_industry[em_hold_industry.CODES.str.contains('.OF')]
+        em_hold_industry['CODES'] = em_hold_industry.apply(lambda x:
                             self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
-        em_hold_industry = em_hold_industry.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        em_hold_industry = em_hold_industry.dropna(subset=['CODES']).drop(columns='_update_time')
         name_dict = {
-            'CODES':'fund_id',
-            'DATES':'datetime',
+            'CODES': 'fund_id',
+            'DATES': 'datetime',
         }
         em_hold_industry = em_hold_industry.rename(columns=name_dict)
         self._data_helper._upload_basic(em_hold_industry, FundHoldIndustry.__table__.name)
