@@ -6,7 +6,7 @@ import pandas as pd
 
 from .fund_score_processor import FundScoreProcessor
 from .fund_indicator_processor import FundIndicatorProcessor
-from .derived_index_val import IndexValProcess
+# from .derived_index_val import IndexValProcess
 from .derived_index_val_long_term import IndexValProcessLongTerm
 from .style_analysis_processor import StyleAnalysisProcessor
 from .derived_data_helper import DerivedDataHelper
@@ -30,7 +30,7 @@ class DerivedDataProcessor:
         self.fund_indicator_processor_monthly = FundIndicatorProcessorMonthly(self._data_helper)
         self.fund_indicator_processor_group = FundIndicatorProcessorGroup(self._data_helper)
         self.fund_score_processor = FundScoreProcessor(self._data_helper)
-        self.index_val_processor = IndexValProcess(self._data_helper)
+        # self.index_val_processor = IndexValProcess(self._data_helper)
         self.index_val_processor_long_term = IndexValProcessLongTerm(self._data_helper)
         self.index_indicator = IndexIndicatorProcessor(self._data_helper)
         self.fund_aip = AIPProcess(self._data_helper)
@@ -49,7 +49,7 @@ class DerivedDataProcessor:
         failed_tasks = []
         failed_tasks.extend(self.fund_indicator_processor.process(start_date, end_date))
         failed_tasks.extend(self.fund_score_processor.process(start_date, end_date))
-        failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
+        # failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
         failed_tasks.extend(self.index_val_processor_long_term.process(start_date, end_date))
         failed_tasks.extend(self.index_indicator.process(end_date))
         failed_tasks.extend(self.fund_aip.process(start_date, end_date))
