@@ -13,6 +13,8 @@ class IndexValProcessLongTerm:
     YEAR = 242
     WINDOW = YEAR * 10
     MIN_PERIOD = YEAR * 5
+    _WINDOW_MINOR = YEAR * 5
+    _MIN_PERIOD_MINOR = YEAR * 3
     SCORE_METHOD = {
         'PB百分位': 'pb_pct',
         'PE百分位': 'pe_pct',
@@ -38,21 +40,28 @@ class IndexValProcessLongTerm:
         self.index_id_score_method_dict = self.index_info[self.index_info['tag_method'] != 'none'][['index_id', 'tag_method']].set_index('index_id').to_dict()['tag_method']
 
     def calculate(self):
-        pctrank = lambda x: pd.Series(x).rank(pct=True).iloc[-1]
+        pctrank = lambda x: x.rank(pct=True).iloc[-1]
         self.index_val = self.index_val.rename(columns={'dividend_yield': 'dy'})
         index_list = self.index_val.index.levels[0].tolist()
         self.result = []
         for index_id in index_list:
-            mins_periods = self.MIN_PERIOD
             df_i = self.index_val.loc[index_id].copy()
-            df_i.loc[:, 'pe_pct'] = df_i['pe_ttm'].tail(self.WINDOW+1).rolling(window=self.WINDOW, min_periods=mins_periods).apply(pctrank)
-            df_i.loc[:, 'pb_pct'] = df_i['pb_mrq'].tail(self.WINDOW+1).rolling(window=self.WINDOW, min_periods=mins_periods).apply(pctrank)
-            df_i.loc[:, 'ps_pct'] = df_i['ps_ttm'].tail(self.WINDOW+1).rolling(window=self.WINDOW, min_periods=mins_periods).apply(pctrank)
-            df_i.loc[:, 'roe_pct'] = df_i['roe'].tail(self.WINDOW+1).rolling(window=self.WINDOW, min_periods=mins_periods).apply(pctrank)
+            df_long_term = df_i[['pe_ttm', 'pb_mrq', 'ps_ttm', 'roe']].tail(self.WINDOW+1)
+            df_i.loc[:, 'pe_pct'] = df_long_term['pe_ttm'].rolling(window=self.WINDOW, min_periods=self.MIN_PERIOD).apply(pctrank, raw=False)
+            df_i.loc[:, 'pb_pct'] = df_long_term['pb_mrq'].rolling(window=self.WINDOW, min_periods=self.MIN_PERIOD).apply(pctrank, raw=False)
+            df_i.loc[:, 'ps_pct'] = df_long_term['ps_ttm'].rolling(window=self.WINDOW, min_periods=self.MIN_PERIOD).apply(pctrank, raw=False)
+            df_i.loc[:, 'roe_pct'] = df_long_term['roe'].rolling(window=self.WINDOW, min_periods=self.MIN_PERIOD).apply(pctrank, raw=False)
+
+            df_minor = df_i[['pe_ttm', 'pb_mrq', 'ps_ttm', 'roe']].tail(self._WINDOW_MINOR+1)
+            df_i.loc[:, 'pe_pct_5_3'] = df_minor['pe_ttm'].rolling(window=self._WINDOW_MINOR, min_periods=self._MIN_PERIOD_MINOR).apply(pctrank, raw=False)
+            df_i.loc[:, 'pb_pct_5_3'] = df_minor['pb_mrq'].rolling(window=self._WINDOW_MINOR, min_periods=self._MIN_PERIOD_MINOR).apply(pctrank, raw=False)
+            df_i.loc[:, 'ps_pct_5_3'] = df_minor['ps_ttm'].rolling(window=self._WINDOW_MINOR, min_periods=self._MIN_PERIOD_MINOR).apply(pctrank, raw=False)
+            df_i.loc[:, 'roe_pct_5_3'] = df_minor['roe'].rolling(window=self._WINDOW_MINOR, min_periods=self._MIN_PERIOD_MINOR).apply(pctrank, raw=False)
+
             df_i['peg_ttm'] = df_i['pe_ttm'] / (df_i['dy'] / df_i['dy'].shift(self.YEAR)-1)
             df_i.loc[:, 'index_id'] = index_id
             self.result.append(df_i)
-            #print(f'finish {index_list.index(index_id)} total: {len(index_list)}')
+            # print(f'finish {index_list.index(index_id)} total: {len(index_list)}')
         self.result = pd.concat(self.result).reset_index()
         score_list = []
         for r in self.result.itertuples(index=False):
@@ -74,14 +83,14 @@ class IndexValProcessLongTerm:
         try:
             start_date_dt = datetime.datetime.strptime(start_date, '%Y%m%d').date()
             end_date_dt = datetime.datetime.strptime(end_date, '%Y%m%d').date()
-            start_date = start_date_dt - datetime.timedelta(days = 3750) #10年历史保险起见，多取几天 10*365=3650
+            start_date = start_date_dt - datetime.timedelta(days=3750)  # 10年历史保险起见，多取几天 10*365=3650
             start_date = datetime.datetime.strftime(start_date, '%Y%m%d')
             self.init(start_date, end_date)
             self.calculate()
-            self.result = self.result.dropna(subset=['pe_ttm','pb_mrq','ps_ttm'], how='all')
+            self.result = self.result.dropna(subset=['pe_ttm', 'pb_mrq', 'ps_ttm'], how='all')
             self.result = self.result[self.result['datetime'] >= pd.to_datetime(start_date_dt)]
             self.result = self.result[self.result['datetime'] <= pd.to_datetime(end_date_dt)]
-            self.result['est_peg'] = self.result['est_peg'].map(lambda x : self.filter_est_peg(x))
+            self.result['est_peg'] = self.result['est_peg'].map(lambda x: self.filter_est_peg(x))
             self._data_helper._upload_derived(self.result, IndexValuationLongTerm.__table__.name)
         except Exception as e:
             print(e)
