@@ -106,7 +106,7 @@ class EmRawDataDownloader:
 
     def em_index_price_history(self, em_ids, start_date, end_date):
         em_id_str = ','.join(em_ids) if isinstance(em_ids, list) else em_ids
-        df = c.csd(em_id_str, "CLOSE", start_date, end_date,
+        df = c.csd(em_id_str, "VOLUME,CLOSE", start_date, end_date,
                    "period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
         if not isinstance(df, pd.DataFrame):
             if df.ErrorCode != 0:
@@ -161,21 +161,23 @@ class EmRawDataDownloader:
                 return None
 
     def em_fund_holding_rate_history(self, end_date: str):
-        fund_id_result = c.sector('507010', end_date)
-        if fund_id_result.ErrorCode != 0:
-            print(f'Failed to get fund id list: {fund_id_result.ErrorMsg}')
-            return
-        y_list = [str(y) for y in range(2020, 2021, 1)]
-        d_list = []
-        for y in y_list:
-            for d in self._semi_update_dates:
-                d_list.append(y + d)
-        for d in d_list:
-            data = c.css(fund_id_result.Codes, "HOLDPERSONALHOLDINGPCT,HOLDINSTIHOLDINGPCT,HOLDNUM", f"ReportDate={d},Ispandas=1")
-            data['DATES'] = d
-            data = data.dropna(how='all').reset_index()
-            self._data_helper._upload_raw(data, EmFundHoldingRate.__table__.name)
-            print(f'finish {d}')
+        fund_list_df = RawDataApi().get_em_fund_list(end_date, limit=1)
+        if fund_list_df is None:
+            print(f'failed to get fund list for fund status')
+        else:
+            fund_list = fund_list_df.all_live_fund_list.array[0].split(',')
+            fund_list += fund_list_df.delisted_fund_list.array[0].split(',')
+            y_list = [str(y) for y in range(2020, 2021, 1)]
+            d_list = []
+            for y in y_list:
+                for d in self._semi_update_dates:
+                    d_list.append(y + d)
+            for d in d_list:
+                data = c.css(fund_list, "HOLDPERSONALHOLDINGPCT,HOLDINSTIHOLDINGPCT,HOLDNUM", f"ReportDate={d},Ispandas=1")
+                data = data[data.drop(columns='DATES').notna().any(axis=1)].reset_index()
+                data['DATES'] = d
+                self._data_helper._upload_raw(data, EmFundHoldingRate.__table__.name)
+                print(f'finish {d}')
 
     def em_fund_nav(self, start_date, end_date, fund_id_list: Tuple[str] = ()):
         try:
@@ -311,7 +313,7 @@ class EmRawDataDownloader:
                     continue
                 future_index.append(one)
             if future_index:
-                data = c.csd(','.join(future_index), "CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
+                data = c.csd(','.join(future_index), "VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
                 if not isinstance(data, pd.DataFrame):
                     if data.ErrorCode != 0:
                         print(f'[em_index_price] failed to get index price: {data.ErrorMsg} (index_id){future_index}')
@@ -319,7 +321,7 @@ class EmRawDataDownloader:
                 df_list.append(data)
 
             # 常规指数部分
-            data = c.csd(','.join(em_ids), "CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
+            data = c.csd(','.join(em_ids), "VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
             if not isinstance(data, pd.DataFrame):
                 if data.ErrorCode != 0:
                     print(f'[em_index_price] failed to get index price: {data.ErrorMsg} (index_id){em_ids}')
@@ -1322,11 +1324,12 @@ class EmRawDataDownloader:
             return False
 
     def em_fund_asset(self, end_date: str):
-        fund_list = RawDataApi().get_em_fund_list(end_date, limit=1)
-        if fund_list is None:
+        fund_list_df = RawDataApi().get_em_fund_list(end_date, limit=1)
+        if fund_list_df is None:
             print(f'failed to get fund list for fund status')
             return False
-        fund_list = fund_list.all_live_fund_list.array[0]
+        fund_list: List[str] = fund_list_df.all_live_fund_list.array[0].split(',')
+        fund_list += fund_list_df.delisted_fund_list.array[0].split(',')
 
         start_year = 2010
         end_year = 2014
@@ -1340,26 +1343,37 @@ class EmRawDataDownloader:
                 res.append(data)
                 print(f'{dt} done')
         df = pd.concat(res).reset_index()
+        df = df[df.drop(columns=['CODES', 'DATES']).notna().any(axis=1)]
         self._data_helper._upload_raw(df, EMFundHoldAsset.__table__.name)
 
-    def em_fund_industry(self):
-        all_fund = c.sector('507013', '20200719').Codes
-        dt_list = ['20191231','20200331','20200630']
+    def em_fund_industry(self, end_date: str):
+        fund_list_df = RawDataApi().get_em_fund_list(end_date, limit=1)
+        if fund_list_df is None:
+            print(f'failed to get fund list for fund status')
+            return False
+        fund_list: List[str] = fund_list_df.all_live_fund_list.array[0].split(',')
+        fund_list += fund_list_df.delisted_fund_list.array[0].split(',')
+
         res = []
-        rank_list = [1,2,3]
-        for dt in dt_list:
-            print(f'doing {dt}')
-            _res = [] 
-            for rank in rank_list:
-                data=c.css(all_fund,"PRTKEYINDNAME,PRTKEYINDTOASSET",f"ReportDate={dt},Rank={rank},IndustryCode=A,NewOldType=1,Ispandas=1")
-                data = data.rename(columns={'PRTKEYINDNAME':f'rank{rank}_indname','PRTKEYINDTOASSET':f'rank{rank}_indweight'})
-                data = data.drop('DATES',axis=1)
-                _res.append(data)
-            df = pd.concat(_res,axis=1)
-            df['DATES'] = dt
-            res.append(df)
-            print(f'{dt} done')
+        start_year = 2015
+        end_year = 2019
+        rank_list = [1, 2, 3]
+        for year in range(start_year, end_year+1):
+            for date in self._quarter_update_dates:
+                dt = str(year) + date
+                print(f'doing {dt}')
+                _res = []
+                for rank in rank_list:
+                    data = c.css(fund_list, "PRTKEYINDNAME,PRTKEYINDTOASSET", f"ReportDate={dt},Rank={rank},IndustryCode=A,NewOldType=1,Ispandas=1")
+                    data = data.rename(columns={'PRTKEYINDNAME':f'rank{rank}_indname','PRTKEYINDTOASSET':f'rank{rank}_indweight'})
+                    data = data.drop(columns='DATES')
+                    _res.append(data)
+                df = pd.concat(_res, axis=1)
+                df['DATES'] = dt
+                res.append(df)
+                print(f'{dt} done')
         df = pd.concat(res).reset_index()
+        df = df[df.drop(columns=['CODES', 'DATES']).notna().any(axis=1)]
         self._data_helper._upload_raw(df, EMFundHoldIndustry.__table__.name)
 
     def em_fund_stock_history(self, fund_stock_path: str, report_date: str):
@@ -1619,4 +1633,4 @@ if __name__ == '__main__':
     # em.em_macroeconomic_price('20200714', '20200714')
     # em.em_fund_fee_history('20200715')
     # em.em_fund_asset('20200819')
-    # em.em_fund_holding_rate_history('20200819')
\ No newline at end of file
+    # em.em_fund_holding_rate_history('20200819')
