@@ -4,8 +4,8 @@ import os
 import datetime
 import traceback
 import requests
-import urllib3
-from ...wrapper.mysql import RawDatabaseConnector
+from ...api.raw import RawDataApi
+from ...view.raw_models import YahooIndexPrice
 from .raw_data_helper import RawDataHelper
 
 
@@ -144,7 +144,25 @@ class WebRawDataDownloader(object):
 
             url_prefix = 'https://query1.finance.yahoo.com/v7/finance/download/'
 
-            start_timestamp = str(int((datetime.datetime.strptime(start_date, '%Y%m%d') - datetime.timedelta(days=7)).timestamp()))
+            trading_day = RawDataApi().get_em_tradedates().set_index('TRADEDATES')
+            start_date_loc = trading_day.index.get_loc(pd.to_datetime(start_date).date(), method='ffill')
+            end_date_loc = trading_day.index.get_loc(pd.to_datetime(end_date).date(), method='ffill')
+
+            assert isinstance(start_date_loc, int), 'start date is not a valid trading day'
+            assert isinstance(end_date_loc, int), 'end date is not a valid trading day'
+
+            # TODO: 由于我们目前更新的时间（次日0点），美股还没收盘，所以这里只能更新前一天的数据；之后再看看可能需要分批做自动更新
+            extra_days = 1
+            assert start_date_loc >= extra_days, 'there is no enough extra days before start date'
+            start_date_with_extra_days = trading_day.index.array[start_date_loc - extra_days]
+            print(f'start date with extra days: {start_date_with_extra_days}')
+
+            assert end_date_loc >= extra_days, 'there is no enough extra days before end date'
+            end_date_with_extra_days = trading_day.index.array[end_date_loc - extra_days]
+            print(f'end date with extra days: {end_date_with_extra_days}')
+
+            start_date = min(pd.to_datetime(start_date, infer_datetime_format=True) - datetime.timedelta(days=7), start_date_with_extra_days)
+            start_timestamp = str(int((start_date).timestamp()))
             end_timestamp = str(int((datetime.datetime.strptime(end_date, '%Y%m%d') + datetime.timedelta(days=1)).timestamp()))
             url_postfix = f'?period1={start_timestamp}&period2={end_timestamp}&interval=1d&events=history'
             url_type_list = ['%5EGSPC', '%5EN225', '%5EGDAXI']
@@ -164,17 +182,17 @@ class WebRawDataDownloader(object):
                 df = pd.read_csv(filename)
                 df = df[['Date', 'Open', 'High', 'Low', 'Close', 'Adj Close', 'Volume']]
                 df.columns = ['datetime', 'open', 'high', 'low', 'close', 'adjclose', 'volume']
-                df['datetime'] = df['datetime'].map(lambda x: datetime.datetime.strptime(x, '%Y-%m-%d'))
+                df['datetime'] = df['datetime'].map(lambda x: pd.to_datetime(x, infer_datetime_format=True).date())
                 df['index_id'] = index_i
                 df['total_turnover'] = float('Nan')
                 df['ret'] = df['adjclose'] / df['adjclose'].shift(1) - 1
                 df = df.drop(['adjclose'], axis=1)
-                df = df[(df['datetime'] >= start_date) & (df['datetime'] <= end_date)].sort_values('datetime')
+                df = df[df['datetime'].between(start_date_with_extra_days, end_date_with_extra_days)].sort_values('datetime')
                 if not df.empty:
                     df_list.append(df)
             if df_list:
                 df_all = pd.concat(df_list)
-                self._data_helper._upload_raw(df_all, 'yahoo_index_price')
+                self._data_helper._upload_raw(df_all, YahooIndexPrice.__table__.name)
             return True
         except Exception as e:
             print(e)
