@@ -1,9 +1,10 @@
 import pandas as pd
 import traceback
+from sqlalchemy import distinct
 from ...wrapper.mysql import DerivedDatabaseConnector, BasicDatabaseConnector, ViewDatabaseConnector
 from ...view.view_models import IndexDailyCollection
 from ...view.basic_models import IndexInfo, IndexPrice, IndexComponent
-from ...view.derived_models import IndexValuation, IndexReturn, IndexVolatility
+from ...view.derived_models import IndexValuationLongTerm, IndexReturn, IndexVolatility
 
 class IndexDailyCollectionProcessor(object):
     def get_index_volatility(self):
@@ -37,23 +38,23 @@ class IndexDailyCollectionProcessor(object):
     def get_index_valuation(self):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
-                latest_time = mn_session.query(IndexValuation).order_by(IndexValuation.datetime.desc()).limit(1).one_or_none()
+                latest_time = mn_session.query(IndexValuationLongTerm).order_by(IndexValuationLongTerm.datetime.desc()).limit(1).one_or_none()
                 latest_time = latest_time.datetime
                 print(latest_time)
                 query = mn_session.query(
-                    IndexValuation.index_id,
-                    IndexValuation.pb_mrq,
-                    IndexValuation.pe_ttm,
-                    IndexValuation.peg_ttm,
-                    IndexValuation.roe,
-                    IndexValuation.dy,
-                    IndexValuation.pe_pct,
-                    IndexValuation.pb_pct,
-                    IndexValuation.ps_pct,
-                    IndexValuation.val_score,
-                    IndexValuation.datetime,
-                    IndexValuation.est_peg,
-                ).filter(IndexValuation.datetime==latest_time)
+                    IndexValuationLongTerm.index_id,
+                    IndexValuationLongTerm.pb_mrq,
+                    IndexValuationLongTerm.pe_ttm,
+                    IndexValuationLongTerm.peg_ttm,
+                    IndexValuationLongTerm.roe,
+                    IndexValuationLongTerm.dy,
+                    IndexValuationLongTerm.pe_pct,
+                    IndexValuationLongTerm.pb_pct,
+                    IndexValuationLongTerm.ps_pct,
+                    IndexValuationLongTerm.val_score,
+                    IndexValuationLongTerm.datetime,
+                    IndexValuationLongTerm.est_peg,
+                ).filter(IndexValuationLongTerm.datetime==latest_time)
                 df = pd.read_sql(query.statement, query.session.bind)
                 df = df.set_index('index_id')
                 return df
@@ -146,6 +147,30 @@ class IndexDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_index_price<err_msg> {}'.format(e))
 
+    def get_index_yesterday_price(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                yest_time = mn_session.query(
+                    distinct(IndexPrice.datetime)
+                ).order_by(
+                    IndexPrice.datetime.desc()
+                ).offset(1).limit(1).one_or_none()
+                yest_time = yest_time[0]
+                print(yest_time)
+                query = mn_session.query(
+                    IndexPrice.index_id,
+                    IndexPrice.close,
+                ).filter(IndexPrice.datetime==yest_time)
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df.rename(columns={
+                    'close': 'yest_close',
+                })
+                df = df.set_index('index_id')
+                return df
+
+            except Exception as e:
+                print('Failed get_index_price<err_msg> {}'.format(e))
+
     def append_data(self, table_name, data_append_directly_data_df):
         if not data_append_directly_data_df.empty:
             with ViewDatabaseConnector().managed_session() as mn_session:
@@ -163,14 +188,15 @@ class IndexDailyCollectionProcessor(object):
         try:
             print('1、 load data...')
             info = self.get_index_info()
-            vol = self.get_index_volatility()
-            ret = self.get_index_return()
-            val = self.get_index_valuation()
-            price = self.get_index_price()
-            component = self.get_index_component()
+            vol = self.get_index_volatility().reindex(info.index)
+            ret = self.get_index_return().reindex(info.index)
+            val = self.get_index_valuation().reindex(info.index)
+            price = self.get_index_price().reindex(info.index)
+            yest_price = self.get_index_yesterday_price().reindex(info.index)
+            component = self.get_index_component().reindex(info.index)
 
             print('2、 concat data...')
-            df = pd.concat([info, vol, ret, val, price, component], axis=1, sort=False)
+            df = pd.concat([info, vol, ret, val, price, yest_price, component], axis=1, sort=False)
             df.index.name = 'index_id'
             df = df.reset_index()
 
