@@ -83,36 +83,12 @@ class FundAlpha(Base):
         Index('idx_fund_alpha_datetime', 'datetime'),
     )
 
-class IndexValuation(Base):
-    '''指数估值'''
-
-    __tablename__ = 'index_valuation'
-    index_id = Column(CHAR(20), primary_key=True) #指数ID
-    datetime = Column(DATE, primary_key=True) # 日期
-
-    pb_mrq = Column(DOUBLE(asdecimal=False)) # 市净率-MRQ
-    pe_ttm = Column(DOUBLE(asdecimal=False)) # 市盈率-MMT
-    roe = Column(DOUBLE(asdecimal=False)) # 净资产收益率
-    ps_ttm = Column(DOUBLE(asdecimal=False)) # 市销率—MMT
-    dy = Column(DOUBLE(asdecimal=False)) # 股息率
-    pcf_ttm = Column(DOUBLE(asdecimal=False)) # 市现率-MMT
-    peg_ttm = Column(DOUBLE(asdecimal=False)) # 市盈率相对盈利增长比率-MMT
-    pe_pct = Column(DOUBLE(asdecimal=False)) # PE百分位
-    pb_pct = Column(DOUBLE(asdecimal=False)) # PB百分位
-    ps_pct = Column(DOUBLE(asdecimal=False)) # PS百分位
-    val_score = Column(DOUBLE(asdecimal=False)) # 估值评分
-    eps_ttm = Column(DOUBLE(asdecimal=False)) # 每股收益—MMT
-    roe_pct = Column(DOUBLE(asdecimal=False)) # ROE百分位
-    est_peg = Column(DOUBLE(asdecimal=False)) # 预测peg
-
-    __table_args__ = (
-        Index('idx_index_valuation_develop_datetime', 'datetime'),
-    )
 
 class IndexValuationLongTerm(Base):
     '''指数估值'''
 
     __tablename__ = 'index_valuation_long_term'
+
     index_id = Column(CHAR(20), primary_key=True) #指数ID
     datetime = Column(DATE, primary_key=True) # 日期
 
@@ -123,18 +99,23 @@ class IndexValuationLongTerm(Base):
     dy = Column(DOUBLE(asdecimal=False)) # 股息率
     pcf_ttm = Column(DOUBLE(asdecimal=False)) # 市现率-MMT
     peg_ttm = Column(DOUBLE(asdecimal=False)) # 市盈率相对盈利增长比率-MMT
-    pe_pct = Column(DOUBLE(asdecimal=False)) # PE百分位
-    pb_pct = Column(DOUBLE(asdecimal=False)) # PB百分位
-    ps_pct = Column(DOUBLE(asdecimal=False)) # PS百分位
-    val_score = Column(DOUBLE(asdecimal=False)) # 估值评分
+    pe_pct = Column(DOUBLE(asdecimal=False)) # PE百分位(10/5年)
+    pb_pct = Column(DOUBLE(asdecimal=False)) # PB百分位(10/5年)
+    ps_pct = Column(DOUBLE(asdecimal=False)) # PS百分位(10/5年)
+    val_score = Column(DOUBLE(asdecimal=False)) # 估值评分(10/5年)
     eps_ttm = Column(DOUBLE(asdecimal=False)) # 每股收益—MMT
-    roe_pct = Column(DOUBLE(asdecimal=False)) # ROE百分位
+    roe_pct = Column(DOUBLE(asdecimal=False)) # ROE百分位(10/5年)
     est_peg = Column(DOUBLE(asdecimal=False)) # 预测peg
+    pe_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PE百分位
+    pb_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PB百分位
+    ps_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PS百分位
+    roe_pct_5_3 = Column(DOUBLE(asdecimal=False)) # ROE百分位
 
     __table_args__ = (
         Index('idx_index_valuation_long_term_datetime', 'datetime'),
     )
 
+
 class FundIndicator(Base):
     '''基金评价指标'''
 
@@ -320,7 +301,7 @@ class FundScoreExtended(Base):
     allocation_rank = Column(DOUBLE(asdecimal=False))  # rank of allocation
     interaction_rank = Column(DOUBLE(asdecimal=False))  # rank of interaction
     total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of total
-    total_rank = Column(DOUBLE(asdecimal=False), nullable=False)  # rank of total
+    total_rank = Column(DOUBLE(asdecimal=False))  # rank of total
 
     __table_args__ = (
         Index('idx_fund_score_extended_datetime', 'datetime'),
