@@ -280,7 +280,7 @@ class EmIndexPrice(Base):
     em_id = Column(CHAR(20), primary_key=True) # Choice代码
     datetime = Column(DATE, primary_key=True) # 日期
     close = Column(DOUBLE(asdecimal=False)) # 收盘价
-
+    volume = Column(DOUBLE(asdecimal=False)) # 交易量
 
 class EmRealtimeIndexPrice(Base):
     '''Choice实时指数数据'''
@@ -1127,18 +1127,21 @@ class EmStockDividend(Base):
     __tablename__ = 'em_stock_dividend'
 
     CODES = Column(CHAR(10), primary_key=True) # 东财基金ID
-    REPORT_DATES = Column(DATE, primary_key=True) # 报告期
     DATES = Column(DATE, primary_key=True) # 日期
+    DIVPROGRESS = Column(CHAR(16)) # 分红方案进度
     DIVCASHPSBFTAX = Column(DOUBLE(asdecimal=False)) # 每股股利(税前)
     DIVSTOCKPS = Column(DOUBLE(asdecimal=False)) # 每股红股
-    DIVPROGRESS = Column(CHAR(16)) # 分红方案进度
+    DIVCAPITALIZATIONPS = Column(DOUBLE(asdecimal=False)) # 每股转增股本
+    DIVPRENOTICEDATE = Column(DATE) # 预披露公告日
+    DIVPLANANNCDATE = Column(DATE) # 预案公告日
+    DIVAGMANNCDATE = Column(DATE) # 股东大会公告日
+    DIVIMPLANNCDATE = Column(DATE) # 分红实施公告日
     DIVRECORDDATE = Column(DATE) # 股权登记日
     DIVEXDATE = Column(DATE) # 除权除息日
-    DIVPRENOTICEDATE = Column(DATE) # 预披露公告日
-    DIVIMPLANNCDATE = Column(DATE) # 分红实施公告日
-    DIVAGMANNCDATE = Column(DATE) # 股东大会公告日
-    DIVPLANANNCDATE = Column(DATE) # 预案公告日
-    DIVORNOT = Column(BOOLEAN) # 是否分红
+    DIVPAYDATE = Column(DATE) # 派息日
+    DIVBONUSLISTEDDATE = Column(DATE) # 送转股份上市交易日
+    DIVOBJ = Column(CHAR(16)) # 分配对象
+    DIVORNOT = Column(CHAR(1)) # 是否分红
 
 class EMMngInfo(Base):
     '''东财基金经理信息表'''
