@@ -38,7 +38,7 @@ class TAAHelper(Helper):
         self.tactic_status = {}
         self.tactic_history = {}
 
-    def on_price(self, dt, asset_price: AssetPrice, cur_saa: AssetWeight, asset_pct: pd.DataFrame, select_val: dict):
+    def on_price(self, dt, asset_price: AssetPrice, cur_saa: AssetWeight, asset_pct: pd.DataFrame, select_val: dict, score_dict: dict):
         taa = cur_saa.copy()
         taa_effected = False
         mode_changed = False
@@ -100,6 +100,7 @@ class TAAHelper(Helper):
             #print(f'{dt} taa mmf less than 0 mmf weight {taa.mmf} tactic_dt {tactic_dt}')
             taa.mmf = 0
         self.rebalance_taa(taa, self.params.TuneCash)
+        self.asset_adjust(taa, score_dict)
         if taa_effected:
             #print(f'taa: {dt} (mode){mode_changed} (taa){taa_effected} (saa){cur_saa} (taa){taa}')
             pass
@@ -125,7 +126,16 @@ class TAAHelper(Helper):
                 continue
             asset_weight[k] /= _sum
 
-
+    def asset_adjust(self, asset_weight:AssetWeight, score_dict:dict):
+        # 如果当前资产没有候选基金，买货基
+        asset_weight = asset_weight.__dict__
+        for k,v in asset_weight.items():
+            if k in score_dict:
+                index_fund_nums = len(list(score_dict[k].keys()))
+                if index_fund_nums == 0:
+                    asset_weight['mmf'] += v
+                    asset_weight[k] -= v
+ 
 class FAHelper(Helper):
     
     def __init__(self, fa_params: FAParam=None):
