@@ -254,6 +254,19 @@ class BasicFundBacktestEngine(object):
         for dt, fund_weight in fund_weight_list:
             dt = dt if isinstance(dt, datetime.date) else datetime.datetime.strptime(dt,'%Y-%m-%d').date()
             self._target_fund_weight[dt] = fund_weight
+        wind_index_map = {
+            '货币市场型基金': 'mmf',
+            '股票型基金': 'hs300',
+            '混合型基金': 'csi500',     # TODO: 临时代替，需设置正确映射关系！！！
+            '国际(QDII)基金': 'sp500rmb',
+            '另类投资基金': 'gold',
+            '债券型基金': 'national_debt',
+            '其他基金': 'hsi'           # TODO: 临时代替，需设置正确映射关系！！！
+        }
+        self._fund_wind_class = {
+            cur.fund_id: (wind_index_map[cur.wind_class_1] if cur.wind_class_1 in wind_index_map else 'hsi') for cur in self._dm.dts.fund_info.itertuples()
+        }
+
 
     def init(self):
         if not self._dm.inited:
@@ -290,11 +303,7 @@ class BasicFundBacktestEngine(object):
 
         curr_target_fund_weight = FundWeight()
         for fund_id, weight in self._target_fund_weight[dt]:
-            # TODO: what if fund_id does not belong to any index! e.g. 000001!0
-            if fund_id in self._dm.dts.fund_index_map:
-                index_id = self._dm.dts.fund_index_map[fund_id]
-            else:
-                index_id = 'hs300' # TODO
+            index_id = self._fund_wind_class[fund_id]
 
             curr_target_fund_weight.add(FundWeightItem(fund_id=fund_id, fund_wgt=weight, 
                                                        index_id=index_id, asset_wgt=0, fund_wgt_in_asset=0))
@@ -766,7 +775,7 @@ params_str_1 = '''
     "back_test_type": "basic",
     "fund_weight_list": [
         [
-            "2020-06-01",
+            "2020-08-05",
             [
                 [
                     "000001!0",
@@ -775,8 +784,8 @@ params_str_1 = '''
             ]
         ]
     ],
-    "start_date": "2020-06-01",
-    "end_date": "2020-08-19"
+    "start_date": "2020-08-05",
+    "end_date": "2020-08-25"
 }
 '''
 
@@ -800,6 +809,8 @@ def test1():
     b.init()
     # print(b._dm.dts.fund_index_map)
     b.run(start_date=start_date, end_date=end_date, print_time=True)
+    print(b.get_fund_result())
+    print(b._report_helper.get_mdd_stats())
 
 if __name__ == '__main__':
     # profile(file_name='/Users/cjiang/taa_perf1.txt', func=fund_backtest)
