@@ -126,17 +126,24 @@ class HybridPainter(object):
         mv_df['benchmark'] = (wgts_df * index_df).sum(axis = 1)
         df = mv_df / mv_df.iloc[0]
         fig, ax = plt.subplots(figsize= [20,12])
+        df['price_ratio'] = df['mv'] / df['benchmark']       
         plt.plot(df.index, df['mv'], label = 'mv', linewidth=2.0)
         plt.plot(df.index, df['benchmark'], label = 'benchmark', linewidth=2.0)
+        plt.plot(df.index, df['price_ratio'], label = 'price ratio', linewidth=2.0)
         
+        stats_res = Calculator.get_stat_result_from_df(df=df.reset_index(), date_column='date', value_column='price_ratio').__dict__
         ar = print_st(bk_stats['annual_ret'])
         av = print_st(bk_stats['annual_vol'])
         sharpe = round(bk_stats['sharpe'],2)
-
         st1 = f'annual_ret : {ar} annual_vol : {av} sharpe : {sharpe}'
         st2 = f'first mdd {print_st(mdd1)} {mdd_date1_1} : {mdd_date1_2}, {mdd_lens1} days'
         st3 = f'second mdd {print_st(mdd2)} {mdd_date2_1} : {mdd_date2_2}, {mdd_lens2} days'
-        st = st1 + '\n' + st2 + '\n' + st3
+        ar_ = print_st(stats_res['annualized_ret'])
+        av_ = print_st(stats_res['annualized_vol'])
+        mdd_ = print_st(stats_res['mdd'])
+        sharpe_ = round(stats_res['sharpe'],2)
+        st4 = f'price ratio annaul ret {ar_} annual vol {av_} mdd {mdd_} sharpe {sharpe_}'
+        st = st1 + '\n' + st2 + '\n' + st3 + '\n' + st4
         plt.legend(fontsize=20 ,loc = 'upper left')
         plt.title(f'market values ', fontsize=30)
         plt.suptitle(st, y=0.87, fontsize=18)
@@ -173,6 +180,19 @@ class HybridPainter(object):
         plt.grid() 
         plt.show()
 
+    @staticmethod
+    def plot_taa_detail(df):
+        df.plot(figsize=(14,8))
+        _res = []
+        for index_id, v in df.iloc[-1].to_dict().items():
+            _res.append(f'{index_id}:{round(v,3)}')
+        s = ' '.join(_res)
+        plt.title('index pct', fontsize=25)
+        plt.legend(loc='lower left', fontsize=15)
+        plt.suptitle(s,y=0.87,fontsize=17)
+        plt.grid()
+        plt.show()
+
     @staticmethod
     def plot_asset_price_ratio(fund_nav:pd.DataFrame, 
                         fund_info:pd.DataFrame, 
@@ -328,4 +348,66 @@ class HybridPainter(object):
         _col_list2 = [_ for _ in _col_list if _ not in _col_list1]
         col_list = _col_list1 + _col_list2
         pos_df = pos_df[col_list]
-        return result_df, pos_df
\ No newline at end of file
+        return result_df, pos_df
+
+    @staticmethod
+    def fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func):
+
+        _res = []
+        indicators = []
+        for k,v in score_func.__dict__.items():
+            if v !=0 :
+                _res.append(f'{k} {round(v,2)}')
+                indicators.append(k)
+        _score_func = ' '.join(_res)  
+        desc_name = fund_info[fund_info['fund_id'] == fund_id].desc_name.values[0]
+        dts_list = sorted(list(score_dict.keys()))
+        res = {}
+        for dt in dts_list:
+            _score_dict = score_dict[dt]
+            if index_id in _score_dict:
+                _score_dict = _score_dict[index_id]
+            else:
+                continue
+            _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
+            _fund_list = [i[0] for i in _score_list]
+            res[dt] = _fund_list
+        _res = []
+        for dt, _fl in res.items():
+            if fund_id in _fl:
+                _res.append({'datetime':dt,'rank':_fl.index(fund_id)})
+        rank_df = pd.DataFrame(_res)
+        rank_df.set_index('datetime').plot(figsize=(16,8))
+        plt.title(f'fund rank {desc_name} {fund_id}', fontsize=25)
+        plt.legend(loc='upper right', fontsize=15)
+        _res = []
+        for i in rank_df.tail().to_dict('records'):
+            _dt = i['datetime']
+            _rank = i['rank']
+            _res.append(f'{_dt} {_rank}')
+        s = _score_func + '\n'+ '\n'.join(_res)
+
+        plt.suptitle(s, y=0.87, fontsize=18)
+        plt.show()
+
+        dl = rank_df.tail().datetime.tolist()
+        result = fund_indicator[(fund_indicator['fund_id'] == fund_id)
+               &(fund_indicator['datetime'].isin(dl))][indicators+['datetime']].set_index('datetime')
+
+        df = fund_nav[[fund_id]].join(index_price[index_id]).dropna()
+        df = df / df.iloc[0]
+        df.loc[:,'price_ratio'] = df[fund_id] / df[index_id]
+        l1 = 3 * 242 + 10 if index_id in ['hs300','csi500'] else 242 + 10
+        l = min(df.shape[0], l1)
+
+        df.iloc[-l:]['price_ratio'].plot(figsize=(16,8))
+        plt.title(f'{fund_id} {desc_name} indicator periods price_ratio', fontsize=25)
+        plt.grid()
+        plt.show()
+
+        df['price_ratio'].plot(figsize=(16,8))
+        plt.title(f'{fund_id} {desc_name} price_ratio', fontsize=25)
+        plt.grid()
+        plt.show()
+
+        return result
\ No newline at end of file
