@@ -461,11 +461,16 @@ class ReportHelper:
                 res.append(dic)
         return pd.DataFrame(res).sort_values(['index_id','score'],ascending=[True,False]).set_index('index_id')
 
-    def get_mdd_stats(self):
+    def get_mdd_recover_stats(self):
         fund_mv = pd.DataFrame([ {'date':k, 'mv':v} for k,v in self.fund_marktet_price_history.items()]).set_index('date')
         res = Calculator.get_mdd_recover_result(fund_mv)
         return res
 
+    def get_mdd_stats(self):
+        fund_mv = pd.DataFrame([ {'date':k, 'mv':v} for k,v in self.fund_marktet_price_history.items()]).set_index('date')
+        res = Calculator.get_mdd_result(fund_mv)
+        return res
+
     @staticmethod
     def plot_fund_score(fund_id:str='200002!0',begin_date:datetime.date=datetime.date(2015,1,1),dm:FundDataManager=None):
         FundPainter.plot_fund_rank(score_dic=dm._score_manager.score_cache,
