@@ -425,6 +425,58 @@ class Calculator:
 
         return res
 
+    @staticmethod
+    def get_mdd_result(mv_df:pandas.DataFrame):
+
+        def _get_mdd_result_df(df:pandas.DataFrame, date_column:str, value_column:str):
+            dates = df[date_column].values
+            values = df[value_column].values
+            return _mdd_analysis(values,dates)
+
+        def _mdd_analysis(values,dates):
+            sr = pandas.Series(values, index=dates).sort_index()
+            if sr.empty:
+                mdd = 0
+                mdd_date1 = None
+                mdd_date2 = None
+                mdd_lens = 0
+                return mdd, mdd_date1, mdd_date2, mdd_lens
+            mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
+            mdd = 1 - mdd_part.min()
+            if mdd == 0:
+                mdd_date1 = None
+                mdd_date2 = None
+                mdd_lens = 0
+            else:
+                mdd_date2 = mdd_part.idxmin()
+                mdd_date1 = sr[:mdd_date2].idxmax()
+                mdd_lens = sr.loc[mdd_date1:mdd_date2].shape[0]
+            return mdd, mdd_date1, mdd_date2, mdd_lens
+
+        mdd1, mdd_date1_1, mdd_date1_2, mdd_lens1 = _get_mdd_result_df(mv_df.reset_index(),'date','mv')
+        mv_df_1 = mv_df.loc[:mdd_date1_1].reset_index()
+        mv_df_2 = mv_df.loc[mdd_date1_2:].reset_index()
+
+        mdd2, mdd_date2_1, mdd_date2_2, mdd_lens2 = _get_mdd_result_df(mv_df_1,'date','mv')
+        mdd3, mdd_date3_1, mdd_date3_2, mdd_lens3 = _get_mdd_result_df(mv_df_2,'date','mv')
+        if mdd3 > mdd2:
+            mdd2 = mdd3
+            mdd_date2_1 = mdd_date3_1
+            mdd_date2_2 = mdd_date3_2
+            mdd_lens2 = mdd_lens3
+
+        res = {
+            'mdd1':mdd1,
+            'mdd1_d1':mdd_date1_1,
+            'mdd1_d2':mdd_date1_2,
+            'mdd1_lens':mdd_lens1,
+            'mdd2':mdd2,
+            'mdd2_d1':mdd_date2_1,
+            'mdd2_d2':mdd_date2_2,
+            'mdd2_len':mdd_lens2
+        }
+
+        return res
 
 
 if __name__ == "__main__":
