@@ -43,6 +43,28 @@ class DbSettings(object):
             self.username, self.host, self.port, self.db_name
         )
 
+class CassandraSettings(object):
+
+    def __init__(self, conf_json):
+        self.hosts = conf_json.get('hosts', '')
+        self.port = conf_json.get('port', '')
+        self.username = conf_json.get('username', '')
+        self.password = conf_json.get('password', '')
+        self.default_key_space = conf_json.get('default_key_space', None)
+
+    def to_dict(self):
+        return {
+            "hosts": self.hosts,
+            "port": self.port,
+            "username": self.username,
+            "password": self.password,
+        }
+
+    def __str__(self):
+        return 'hosts:{} ** port:{} ** username:{}** password:{}'.format(
+            self.hosts, self.port, self.username, self.password,
+        )
+
 class SurfingConfigurator(metaclass=Singleton):
 
     def __init__(self, config_path=DEFAULT_CONFIG_PATH):
@@ -71,3 +93,7 @@ class SurfingConfigurator(metaclass=Singleton):
         assert 'wechat_webhook' in self.config, 'could not find wechat_webhook section in config'
         settings = self.config['wechat_webhook']
         return settings
+
+    def get_cassandra_setting(self):
+        assert 'surfing_cassandra' in self.config, 'could not find surfing_cassandra section in config'
+        return CassandraSettings(self.config['surfing_cassandra'])
